@@ -3,10 +3,12 @@ from . import _version
 __version__ = _version.get_versions()['version']
 
 from .drb_driver_java_node import DrbJavaBaseNode, DrbJavaNode
+from .drb_driver_java_factory import DrbJavaFactory
 
 del _version
 
 __all__ = [
     'DrbJavaNode',
     'DrbJavaBaseNode',
+    'DrbJavaFactory'
 ]
